# Contributing to model-ensembler
Contributions are welcome, and they are greatly appreciated! Every little bit
helps, and credit will always be given.

Please note that this project is released
with a [Contributor Code of Conduct](code_of_conduct.md).

## Types of Contributions

You can contribute in many ways:

### Open an Issue
Open an issue on [Github](https://github.com/antarctica/model-ensembler/issues).

If you are reporting a bug, please include:

* Your operating system name and version.
* Any details about your local setup that might be helpful in troubleshooting.
* Detailed steps to reproduce the bug.

### Fix Bugs
Look through the GitHub issues for bugs. Anything tagged with "bug" and "help
wanted" is open to whoever wants to implement it.

### Implement Features
Look through the GitHub issues for features. Anything tagged with "enhancement"
and "help wanted" is open to whoever wants to implement it.

### Write Documentation
The `model-ensembler` documentation can always be improved, whether as part of the
official docs, in docstrings, or even on the web in blog posts, articles, and such.

### Submit Feedback
The best way to send feedback is to [open an issue](https://github.com/antarctica/model-ensembler/issues).

If you are proposing a feature:

* Explain in detail how it would work.
* Keep the scope as narrow as possible, to make it easier to implement.
* Remember that this is a volunteer-driven project, and that contributions
  are welcome.